@@ -11,7 +11,7 @@ class TQCheckBox;
 class KLineEdit;
 class KPushButton;
 // class KURLRequester;
-class KListBox;
+class TDEListBox;
 
 /**
  * @short The Replay Gain Tool
@@ -21,7 +21,7 @@ class KListBox;
 class DirDialog : public KDialog
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     enum Mode {
         Convert    = 0x0001,
@@ -53,7 +53,7 @@ private:
 //     KURLRequester* uDirectory;
     KLineEdit* lDirectory;
     KPushButton* pDirectory;
-    KListBox* fileTypes;
+    TDEListBox* fileTypes;
     KPushButton* pSelectAll;
     KPushButton* pSelectNone;
     TQCheckBox* cRecursive;
